@@ -28,18 +28,18 @@ MGUS_death_prog <- estimateCompetingRiskSurvival(cdm,
   targetCohortTable = "mgus_diagnosis",
   outcomeCohortTable = "progression",
   competingOutcomeCohortTable = "death_cohort"
-)
+) 
 
 MGUS_death_prog %>% 
+  asSurvivalResult() %>% 
   glimpse()
 
 ## -----------------------------------------------------------------------------
-plotCumulativeIncidence(MGUS_death_prog, 
-                        colour = "variable_level")
+plotSurvival(MGUS_death_prog, cumulativeFailure = TRUE,
+             colour = "variable_level")
 
 ## -----------------------------------------------------------------------------
-MGUS_death_prog %>% dplyr::filter(estimate_type == "Survival summary") %>%
-  tidyr::pivot_wider(names_from = "estimate_name", values_from = "estimate_value")
+tableSurvival(MGUS_death_prog, times = c(100,200,300,400)) 
 
 ## -----------------------------------------------------------------------------
 MGUS_death_prog <-  estimateCompetingRiskSurvival(cdm,
@@ -51,15 +51,14 @@ MGUS_death_prog <-  estimateCompetingRiskSurvival(cdm,
 
 
 ## ----fig.height=6, fig.width=8------------------------------------------------
-
-plotCumulativeIncidence(MGUS_death_prog  %>%
-                          dplyr::filter(strata_name != "Overall"), 
-                        facet = "strata_level",
-                        colour = "variable_level")
+plotSurvival(MGUS_death_prog %>% 
+               dplyr::filter(strata_name != "Overall"), 
+             facet = "strata_level",
+             colour = "variable_level",
+             cumulativeFailure = TRUE)
 
 ## -----------------------------------------------------------------------------
-MGUS_death_prog %>% dplyr::filter(estimate_type == "Survival summary") %>%
-  tidyr::pivot_wider(names_from = "estimate_name", values_from = "estimate_value")
+tableSurvival(MGUS_death_prog, times = c(50,150,365))
 
 ## -----------------------------------------------------------------------------
 MGUS_death_prog <- estimateCompetingRiskSurvival(cdm,
@@ -67,7 +66,7 @@ MGUS_death_prog <- estimateCompetingRiskSurvival(cdm,
   outcomeCohortTable = "progression",
   competingOutcomeCohortTable = "death_cohort",
   returnParticipants = TRUE
-)
+) 
 survivalParticipants(MGUS_death_prog)
 
 ## -----------------------------------------------------------------------------
